@@ -1,4 +1,4 @@
-from .client import Client, BandwidthUsage
+from .client import Client, BandwidthUsage, Attachment
 from .usercookie import UserCookie
 from .options import RequestOptions
 from .objects import *
