@@ -1,4 +1,4 @@
-from typing import Optional, Dict, OrderedDict, Any, Union, Literal, Tuple, NamedTuple
+from typing import Optional, Dict, OrderedDict, Any, Union, Literal, Tuple
 from dataclasses import dataclass, field
 
 import requests
