@@ -6,6 +6,7 @@ import logging
 import urllib3
 import json
 import io
+import mimetypes
 
 import requests
 import requests_toolbelt
@@ -19,6 +20,19 @@ from .objects import Board, ThreadPage, BoardThread
 from .exceptions import ShouldNotReachException, RequiresLoginException, NoPermissionException, ResourceNotExistsException, GatekeptException, UnknownResponseException, ReplyException
 
 
+@dataclass(frozen=True)
+class Attachment:
+    name: str
+    file: bytes
+    content_type: Optional[str] = None
+
+    def __post_init__(self):
+        if not self.content_type:
+            content_type = mimetypes.guess_type(self.name)
+            if content_type:
+                object.__setattr__(self, 'content_type', content_type[0])
+
+
 @dataclass
 class Client(BaseClient):
     """
@@ -164,6 +178,7 @@ class Client(BaseClient):
 
     def reply_thread(self, content: str, to_thread_id: int,
                      name: Optional[str] = None, email: Optional[str] = None, title: Optional[str] = None,
+                     attachment: Optional[Attachment] = None,
                      options: RequestOptions = {}):
         session = self._make_session(options, needs_login=True)
         data: OrderedDict[str, str] = OrderedDict()
@@ -174,13 +189,17 @@ class Client(BaseClient):
         data['email'] = (None, email if email is not None else "")
         data['title'] = (None, title if title is not None else "")
         data['resto'] = (None, str(to_thread_id))
+        if attachment:
+            data['image'] = (attachment.name, attachment.file,
+                             attachment.content_type)
+            data['fileName'] = attachment.name
 
         resp_body = None
         with session.post(url=f'https://{self.host}/Home/Forum/doReplyThread.html', files=data) as resp:
             resp.raise_for_status()
             resp_body = resp.text
 
-        doc = BeautifulSoup(resp_body)
+        doc = BeautifulSoup(resp_body, features='html.parser')
         sys_msg_div = doc.find('div', attrs={'class': 'system-message'})
         if sys_msg_div is None:
             raise UnknownResponseException(response_body=resp.text)
