@@ -19,6 +19,10 @@ class ClientException(Exception):
     message: str
     """记载可读的异常信息。"""
 
+    def __init__(self, message: str):
+        self.message = message
+        super(ClientException, self).__init__(self, self.message)
+
 
 @dataclass
 class NoPermissionException(ClientException):
